@@ -29,6 +29,8 @@ pub(crate) struct Config {
   pub(crate) subcommand:           Subcommand,
   pub(crate) unsorted:             bool,
   pub(crate) unstable:             bool,
+  pub(crate) dotenv_filename:      Option<String>,
+  pub(crate) dotenv_path:          Option<PathBuf>,
   pub(crate) verbosity:            Verbosity,
 }
 
@@ -96,6 +98,8 @@ mod arg {
   pub(crate) const SHELL_COMMAND: &str = "SHELL-COMMAND";
   pub(crate) const UNSORTED: &str = "UNSORTED";
   pub(crate) const UNSTABLE: &str = "UNSTABLE";
+  pub(crate) const DOTENV_FILENAME: &str = "DOTENV_FILENAME";
+  pub(crate) const DOTENV_PATH: &str = "DOTENV_PATH";
   pub(crate) const VERBOSE: &str = "VERBOSE";
   pub(crate) const WORKING_DIRECTORY: &str = "WORKING-DIRECTORY";
 
@@ -317,6 +321,19 @@ impl Config {
           .long("variables")
           .help("List names of variables"),
       )
+      .arg(
+        Arg::with_name(arg::DOTENV_FILENAME)
+          .long("dotenv-filename")
+          .takes_value(true)
+          .help("Search for environment file named <DOTENV-FILENAME> instead of `.env`")
+          .conflicts_with(arg::DOTENV_PATH),
+      )
+      .arg(
+        Arg::with_name(arg::DOTENV_PATH)
+          .long("dotenv-path")
+          .help("Load environment file at <DOTENV-PATH> instead of searching for one")
+          .takes_value(true),
+      )
       .group(ArgGroup::with_name("SUBCOMMAND").args(cmd::ALL))
       .arg(
         Arg::with_name(arg::ARGUMENTS)
@@ -537,6 +554,8 @@ impl Config {
       shell_args,
       shell_present,
       subcommand,
+      dotenv_filename: matches.value_of(arg::DOTENV_FILENAME).map(str::to_owned),
+      dotenv_path: matches.value_of(arg::DOTENV_PATH).map(PathBuf::from),
       verbosity,
     })
   }
@@ -566,7 +585,7 @@ mod tests {
   // have proper tests for all the flags, but this will do for now.
   #[test]
   fn help() {
-    const EXPECTED_HELP: &str = "just 0.10.0
+    const EXPECTED_HELP: &str = "just 0.10.1
 Casey Rodarmor <casey@rodarmor.com>
 🤖 Just a command runner \
                                  - https://github.com/casey/just
@@ -576,17 +595,18 @@ USAGE:
 
 FLAGS:
         --changelog           Print changelog
-        --choose              Select one or more recipes to run using a binary. If `--chooser` is \
-                                 not passed the chooser
-                              defaults to the value of $JUST_CHOOSER, falling back to `fzf`
+        --choose              Select one or more recipes to run using a binary.
+                              If `--chooser` is not passed the chooser defaults
+                              to the value of $JUST_CHOOSER, falling back to
+                              `fzf`
         --clear-shell-args    Clear shell arguments
         --dry-run             Print what just would do without doing it
         --dump                Print entire justfile
-    -e, --edit                Edit justfile with editor given by $VISUAL or $EDITOR, falling back \
-                                 to `vim`
-        --evaluate            Evaluate and print all variables. If a variable name is given as an \
-                                 argument, only print
-                              that variable's value.
+    -e, --edit                Edit justfile with editor given by $VISUAL or
+                              $EDITOR, falling back to `vim`
+        --evaluate            Evaluate and print all variables. If a variable
+                              name is given as an argument, only print that
+                              variable's value.
         --fmt                 Format and overwrite justfile
         --highlight           Highlight echoed recipe lines in bold
         --init                Initialize new justfile in project root
@@ -594,8 +614,8 @@ FLAGS:
         --no-dotenv           Don't load `.env` file
         --no-highlight        Don't highlight echoed recipe lines in bold
     -q, --quiet               Suppress all output
-        --shell-command       Invoke <COMMAND> with the shell used to run recipe lines and \
-                                 backticks
+        --shell-command       Invoke <COMMAND> with the shell used to run recipe
+                              lines and backticks
         --summary             List names of available recipes
     -u, --unsorted            Return list and summary entries in source order
         --unstable            Enable unstable features
@@ -603,34 +623,52 @@ FLAGS:
     -v, --verbose             Use verbose output
 
 OPTIONS:
-        --chooser <CHOOSER>                        Override binary invoked by `--choose`
+        --chooser <CHOOSER>
+            Override binary invoked by `--choose`
+
         --color <COLOR>
-            Print colorful output [default: auto]  [possible values: auto, always, never]
-
+            Print colorful output [default: auto]  [possible values: auto,
+            always, never]
     -c, --command <COMMAND>
-            Run an arbitrary command with the working directory, `.env`, overrides, and exports set
-
+            Run an arbitrary command with the working directory, `.env`,
+            overrides, and exports set
         --completions <SHELL>
-            Print shell completion script for <SHELL> [possible values: zsh, bash, fish, \
-                                 powershell, elvish]
+            Print shell completion script for <SHELL> [possible values: zsh,
+            bash, fish, powershell, elvish]
+        --dotenv-filename <DOTENV_FILENAME>
+            Search for environment file named <DOTENV-FILENAME> instead of
+            `.env`
+        --dotenv-path <DOTENV_PATH>
+            Load environment file at <DOTENV-PATH> instead of searching for one
 
     -f, --justfile <JUSTFILE>                      Use <JUSTFILE> as justfile
         --list-heading <TEXT>                      Print <TEXT> before list
-        --list-prefix <TEXT>                       Print <TEXT> before each list item
-        --set <VARIABLE> <VALUE>                   Override <VARIABLE> with <VALUE>
-        --shell <SHELL>                            Invoke <SHELL> to run recipes [default: sh]
-        --shell-arg <SHELL-ARG>...                 Invoke shell with <SHELL-ARG> as an argument \
-                                 [default: -cu]
-    -s, --show <RECIPE>                            Show information about <RECIPE>
-    -d, --working-directory <WORKING-DIRECTORY>
-            Use <WORKING-DIRECTORY> as working directory. --justfile must also be set
+        --list-prefix <TEXT>
+            Print <TEXT> before each list item
 
+        --set <VARIABLE> <VALUE>
+            Override <VARIABLE> with <VALUE>
+
+        --shell <SHELL>
+            Invoke <SHELL> to run recipes [default: sh]
+
+        --shell-arg <SHELL-ARG>...
+            Invoke shell with <SHELL-ARG> as an argument [default: -cu]
+
+    -s, --show <RECIPE>
+            Show information about <RECIPE>
+
+    -d, --working-directory <WORKING-DIRECTORY>
+            Use <WORKING-DIRECTORY> as working directory. --justfile must also
+            be set
 
 ARGS:
-    <ARGUMENTS>...    Overrides and recipe(s) to run, defaulting to the first recipe in the \
-                                 justfile";
+    <ARGUMENTS>...    Overrides and recipe(s) to run, defaulting to the
+                      first recipe in the justfile";
 
-    let app = Config::app().setting(AppSettings::ColorNever);
+    let app = Config::app()
+      .setting(AppSettings::ColorNever)
+      .set_term_width(80);
     let mut buffer = Vec::new();
     app.write_help(&mut buffer).unwrap();
     let help = str::from_utf8(&buffer).unwrap();
@@ -870,6 +908,11 @@ ARGS:
     verbosity: Verbosity::Quiet,
   }
 
+  error! {
+    name: dotenv_both_filename_and_path,
+    args: ["--dotenv-filename", "foo", "--dotenv-path", "bar"],
+  }
+
   test! {
     name: set_default,
     args: [],
