@@ -23,7 +23,7 @@ pub(crate) fn config(args: &[&str]) -> Config {
 
 pub(crate) fn search(config: &Config) -> Search {
   let working_directory = config.invocation_directory.clone();
-  let justfile = working_directory.join(crate::search::FILENAME);
+  let justfile = working_directory.join("justfile");
 
   Search {
     justfile,
@@ -61,16 +61,16 @@ pub(crate) fn analysis_error(
   line: usize,
   column: usize,
   length: usize,
-  kind: CompilationErrorKind,
+  kind: CompileErrorKind,
 ) {
   let tokens = Lexer::lex(src).expect("Lexing failed in parse test...");
 
-  let module = Parser::parse(&tokens).expect("Parsing failed in analysis test...");
+  let ast = Parser::parse(&tokens).expect("Parsing failed in analysis test...");
 
-  match Analyzer::analyze(module) {
+  match Analyzer::analyze(ast) {
     Ok(_) => panic!("Analysis unexpectedly succeeded"),
     Err(have) => {
-      let want = CompilationError {
+      let want = CompileError {
         token: Token {
           kind: have.token.kind,
           src,
