@@ -2,8 +2,6 @@ use crate::common::*;
 
 #[derive(Clone, Debug, PartialEq)]
 pub(crate) enum Warning {
-  // Remove this on 2021-07-01.
-  #[allow(dead_code)]
   DotenvLoad,
 }
 
@@ -15,10 +13,10 @@ impl Warning {
   }
 }
 
-impl Display for Warning {
-  fn fmt(&self, f: &mut Formatter) -> fmt::Result {
-    let warning = Color::fmt(f).warning();
-    let message = Color::fmt(f).message();
+impl ColorDisplay for Warning {
+  fn fmt(&self, f: &mut Formatter, color: Color) -> fmt::Result {
+    let warning = color.warning();
+    let message = color.message();
 
     write!(f, "{} {}", warning.paint("warning:"), message.prefix())?;
 
@@ -27,6 +25,7 @@ impl Display for Warning {
         #[rustfmt::skip]
         write!(f, "\
 A `.env` file was found and loaded, but this behavior will change in the future.
+
 To silence this warning and continue loading `.env` files, add:
 
     set dotenv-load := true
@@ -35,6 +34,12 @@ To silence this warning and stop loading `.env` files, add:
 
     set dotenv-load := false
 
+This warning may also be silenced by setting the `JUST_SUPPRESS_DOTENV_LOAD_WARNING`
+environment variable to `1`. This can be used to silence the warning globally by
+adding the following line to your shell rc file:
+
+  export JUST_SUPPRESS_DOTENV_LOAD_WARNING=1
+
 See https://github.com/casey/just/issues/469 for more details.")?;
       },
     }
@@ -43,7 +48,7 @@ See https://github.com/casey/just/issues/469 for more details.")?;
 
     if let Some(token) = self.context() {
       writeln!(f)?;
-      token.write_context(f, Color::fmt(f).warning())?;
+      write!(f, "{}", token.color_display(color))?;
     }
 
     Ok(())
