@@ -149,10 +149,22 @@ test! {
       echo {{ a }}
   ",
   args: ("--dump"),
-  stdout: format!("
-    a := if '' == '' {{ '' }} else {{ '' }}{}
+  stdout: "
+    a := if '' == '' { '' } else { '' }
 
     foo:
-        echo {{{{a}}}}
-  ", " ").as_str(),
+        echo {{ a }}
+  ",
+}
+
+test! {
+  name: if_else,
+  justfile: "
+    x := if '0' == '1' { 'a' } else if '0' == '0' { 'b' } else { 'c' }
+
+    foo:
+      echo {{ x }}
+  ",
+  stdout: "b\n",
+  stderr: "echo b\n",
 }
