@@ -3,11 +3,10 @@ mod test;
 
 mod assert_stdout;
 mod assert_success;
-mod common;
-mod tempdir;
-
+mod changelog;
 mod choose;
 mod command;
+mod common;
 mod completions;
 mod conditional;
 mod delimiters;
@@ -29,6 +28,9 @@ mod readme;
 mod search;
 mod shebang;
 mod shell;
+mod show;
 mod string;
 mod sublime_syntax;
+mod subsequents;
+mod tempdir;
 mod working_directory;
