@@ -123,30 +123,6 @@ test! {
   status: EXIT_FAILURE,
 }
 
-test! {
-  name: alias_show,
-  justfile: "foo:\n    bar\nalias f := foo",
-  args: ("--show", "f"),
-  stdout: "
-    alias f := foo
-    foo:
-        bar
-  ",
-}
-
-test! {
-  name: alias_show_missing_target,
-  justfile: "alias f := foo",
-  args: ("--show", "f"),
-  stderr: "
-    error: Alias `f` has an unknown target `foo`
-      |
-    1 | alias f := foo
-      |       ^
-  ",
-  status: EXIT_FAILURE,
-}
-
 test! {
   name:     default,
   justfile: "default:\n echo hello\nother: \n echo bar",
@@ -256,19 +232,6 @@ c:
   stderr:   "echo d\necho c\n",
 }
 
-test! {
-  name:     show,
-  justfile: r#"hello := "foo"
-bar := hello + hello
-recipe:
- echo {{hello + "bar" + bar}}"#,
-  args:     ("--show", "recipe"),
-  stdout:   r#"
-    recipe:
-        echo {{ hello + "bar" + bar }}
-  "#,
-}
-
 test! {
   name:     status_passthrough,
   justfile: "
@@ -700,8 +663,8 @@ test! {
   justfile: "b := a\na := `exit 100`\nbar:\n echo '{{`exit 200`}}'",
   args:     ("--color", "always"),
   stdout:   "",
-  stderr:   "\u{1b}[1;31merror\u{1b}[0m: \u{1b}[1mBacktick failed with exit code 100
-\u{1b}[0m  |\n2 | a := `exit 100`\n  |      \u{1b}[1;31m^^^^^^^^^^\u{1b}[0m\n",
+  stderr:   "\u{1b}[1;31merror\u{1b}[0m: \u{1b}[1mBacktick failed with exit code 100\u{1b}[0m
+  |\n2 | a := `exit 100`\n  |      \u{1b}[1;31m^^^^^^^^^^\u{1b}[0m\n",
   status:   100,
 }
 
@@ -1021,66 +984,6 @@ b:
   "#,
 }
 
-test! {
-  name:     show_suggestion,
-  justfile: r#"
-hello a b='B	' c='C':
-  echo {{a}} {{b}} {{c}}
-
-a Z="\t z":
-"#,
-  args:     ("--show", "hell"),
-  stdout:   "",
-  stderr:   "Justfile does not contain recipe `hell`.\nDid you mean `hello`?\n",
-  status:   EXIT_FAILURE,
-}
-
-test! {
-  name:     show_alias_suggestion,
-  justfile: r#"
-hello a b='B	' c='C':
-  echo {{a}} {{b}} {{c}}
-
-alias foo := hello
-
-a Z="\t z":
-"#,
-  args:     ("--show", "fo"),
-  stdout:   "",
-  stderr:   "Justfile does not contain recipe `fo`.\nDid you mean `foo`, an alias for `hello`?\n",
-  status:   EXIT_FAILURE,
-}
-
-test! {
-  name:     show_no_suggestion,
-  justfile: r#"
-helloooooo a b='B	' c='C':
-  echo {{a}} {{b}} {{c}}
-
-a Z="\t z":
-"#,
-  args:     ("--show", "hell"),
-  stdout:   "",
-  stderr:   "Justfile does not contain recipe `hell`.\n",
-  status:   EXIT_FAILURE,
-}
-
-test! {
-  name:     show_no_alias_suggestion,
-  justfile: r#"
-hello a b='B	' c='C':
-  echo {{a}} {{b}} {{c}}
-
-alias foo := hello
-
-a Z="\t z":
-"#,
-  args:     ("--show", "fooooooo"),
-  stdout:   "",
-  stderr:   "Justfile does not contain recipe `fooooooo`.\n",
-  status:   EXIT_FAILURE,
-}
-
 test! {
   name:     run_suggestion,
   justfile: r#"
